--
-- Sneekee Mods - Simple UI and Zone Map Changes
-- Author: Polgara97
--

local DEFAULTS = {
    profile = {
        autoshow = true,
	bgonly = false,
	hideedges = true,
	hideclose = true,
	fpsmon = true,
	fpsmonon = true,
	hidegryph = true,
        mapsize = 1.0,
        hidequests = true,
        hidemacro = false,
        hidekeybinds = false,
        hidequests = false,
        fpscolor = true,
	acamignore = true,
	acamon = false,
	acambasic = false,
    },
}

--------------------------------------------------------------------------------
-- Initialization
--------------------------------------------------------------------------------
SneekeeMods = LibStub("AceAddon-3.0"):NewAddon("SneekeeMods", "AceConsole-3.0", "AceEvent-3.0")

local loadAttempt = 1; -- Fix Ace/Blizz issue with showing the wrong screen on first call

function SneekeeMods:OnInitialize()
    -- User's settings
    self.db = LibStub("AceDB-3.0"):New("SneekeeModsDB", DEFAULTS, true)

    LibStub("AceConfig-3.0"):RegisterOptionsTable("SneekeeMods", SneekeeModsConfig.AceConfig)
    self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("SneekeeMods", "SneekeeMods")
    self:RegisterChatCommand("snke", "ChatCommand")
    self:RegisterChatCommand("sneekee", "ChatCommand")
end

function SneekeeMods:ChatCommand(input)
    if not input or input:trim() == "" then
        if loadAttempt == 1 then -- Fix Ace/Blizz issue with showing the wrong screen on first call
            loadAttempt = loadAttempt + 1;
            InterfaceOptionsFrame_OpenToCategory(self.optionsFrame);
        end
        InterfaceOptionsFrame_OpenToCategory(self.optionsFrame);
    elseif input:trim() == "gar" then
        ShowGarrisonLandingPage(2);
    else
        LibStub("AceConfigCmd-3.0"):HandleCommand("snke", "SneekeeMods", input);
        self:Print("Don't be sneekee!");
    end
end

--------------------------------------------------------------------------------
-- Register events & commands
--------------------------------------------------------------------------------
--SneekeeMods:RegisterEvent("PLAYER_ENTERING_WORLD")

--------------------------------------------------------------------------------
-- FPS Monitor
--------------------------------------------------------------------------------
local timer = 0;
local FPS_Tracking_Frame = CreateFrame ( "Frame" , "FPS_Tracking_Frame" , UIParent );
local FPS_Tracking_FrameText = FPS_Tracking_Frame:CreateFontString ( "FPS_Tracking_FrameText" , "OVERLAY" , "GameFontNormal" );
-- Core Frame
--FPS_Tracking_Frame:ClearAllPoints(); --RESET
--FPS_Tracking_Frame:SetPoint("CENTER" , UIPanel); --RESET
--FPS_Tracking_Frame:SetPoint(0,0); --RESET
FPS_Tracking_Frame:SetPoint ( "CENTER" , UIParent );
FPS_Tracking_Frame:SetSize ( 75 , 15 );
FPS_Tracking_Frame:EnableMouse ( true );
FPS_Tracking_Frame:SetMovable ( true );
FPS_Tracking_Frame:SetUserPlaced ( true );
FPS_Tracking_Frame:SetToplevel ( true );
FPS_Tracking_Frame:RegisterForDrag ( "LeftButton" );
FPS_Tracking_Frame:SetScript ( "OnDragStart" , FPS_Tracking_Frame.StartMoving );
FPS_Tracking_Frame:SetScript ( "OnDragStop" , FPS_Tracking_Frame.StopMovingOrSizing );
-- Text
FPS_Tracking_FrameText:SetPoint ( "LEFT" , FPS_Tracking_Frame );
FPS_Tracking_FrameText:SetFont ( STANDARD_TEXT_FONT , 16 );
FPS_Tracking_FrameText:Hide();
    
FPS_Tracking_Frame:SetScript ( "OnUpdate" , function ( self , elapsed )
    timer = timer + elapsed;
    if timer > 0.05 then
        if FramerateLabel:IsVisible() then
            FPS_Tracking_FrameText:Show();
            if (FramerateText:GetText() ~= nil) then
                FPS_Tracking_FrameText:SetText ( "FPS: " .. FramerateText:GetText() );
            end
        else
            FPS_Tracking_FrameText:Hide();
        end
        timer = 0;
    end
end);

function SneekeeMods:CheckFPSMonitor()
    if self.db.profile.fpsmon then
        -- Going to make the other frame invisible
        FramerateLabel:SetTextColor ( 1 , 1 , 1 , 0 );
        FramerateText:SetTextColor ( 1 , 1 , 1 , 0 );
        FPS_Tracking_Frame:Show();
    else
        -- Don't show the new monitor
        FPS_Tracking_Frame:Hide();
        FramerateLabel:SetTextColor ( 1 , 1 , 1 );
        FramerateText:SetTextColor ( 1 , 1 , 1 );
    end
end

function SneekeeMods:CheckFPSColor()
    if self.db.profile.fpscolor then
        FPS_Tracking_FrameText:SetTextColor ( 0.5 , 0.5 , 0.5 , 1 );
    else
        FPS_Tracking_FrameText:SetTextColor ( 1 , 0.96 , 0.41 );
    end
end

--------------------------------------------------------------------------------
-- Main
--------------------------------------------------------------------------------
function SneekeeMods:OnEnable()
    SneekeeMods:CheckGryphons();

    -- Zone Minimap (shift-m map)
    -- local scale = 0.88
    local scale = self.db.profile.mapsize
    local f = CreateFrame("Frame")
    local SetMiniMap = function()
        BattlefieldMapFrame:SetScale(scale);
        SneekeeMods:CheckMapEdges();
        SneekeeMods:CheckCloseButton();
        BattlefieldMapFrame:Hide();

        if self.db.profile.bgonly == false then
            BattlefieldMapFrame:Show();
        elseif self.db.profile.bgonly == true then
            if UnitInBattleground("player") then
                BattlefieldMapFrame:Show();
            else
                BattlefieldMapFrame:Hide();
            end
        end

    end
    f:SetScript("OnEvent",function()
        if not BattlefieldMapFrame then
            LoadAddOn("Blizzard_BattlefieldMapFrame")BattlefieldMap_LoadUI();
        end
         SetMiniMap();
    end)
    if self.db.profile.autoshow == true then
        f:RegisterEvent("ZONE_CHANGED")
        f:RegisterEvent("ZONE_CHANGED_NEW_AREA")
        f:RegisterEvent("PLAYER_ENTERING_WORLD")
    end

    if self.db.profile.hidequests then
        SneekeeMods:CollapseQuests();
    end

    SneekeeMods:CheckFPSMonitor();

    SneekeeMods:CheckFPSColor();

    if self.db.profile.fpsmonon then
        ToggleFramerate();
    end

    -- Modify Action Bar Buttons
    local function FixButton(button)
        if self.db.profile.hidekeybinds then
            button.HotKey:SetAlpha(0)  -- Hide keybinds on buttons
        end
        if self.db.profile.hidemacro then
            button.Name:Hide()         -- Hide macro names on buttons
        end    
    end
    for i = 1, 12 do
        FixButton(_G["MultiBarBottomLeftButton"..i])
        FixButton(_G["MultiBarBottomRightButton"..i])
        FixButton(_G["ActionButton"..i])
        FixButton(_G["MultiBarRightButton"..i])
        FixButton(_G["MultiBarLeftButton"..i])
    end

    SneekeeMods:CheckActionCam();

end


--------------------------------------------------------------------------------
-- Map Size
--------------------------------------------------------------------------------
function SneekeeMods:ChangeMapSize()
    BattlefieldMapFrame:SetScale(self.db.profile.mapsize);
end

--------------------------------------------------------------------------------
-- Map Edges
--------------------------------------------------------------------------------
function SneekeeMods:CheckMapEdges()
    if self.db.profile.hideedges then
        SneekeeMods:HideMapEdges();
    else
        SneekeeMods:ShowMapEdges();
    end
end
function SneekeeMods:HideMapEdges()
    BattlefieldMapFrame.BorderFrame.Top:Hide();
    BattlefieldMapFrame.BorderFrame.TopLeft:Hide();
    BattlefieldMapFrame.BorderFrame.TopRight:Hide();
    BattlefieldMapFrame.BorderFrame.Left:Hide();
    BattlefieldMapFrame.BorderFrame.BottomLeft:Hide();
    BattlefieldMapFrame.BorderFrame.Right:Hide();
    BattlefieldMapFrame.BorderFrame.BottomRight:Hide();
    BattlefieldMapFrame.BorderFrame.Bottom:Hide();
    BattlefieldMapFrame.BorderFrame.CloseButtonBorder:Hide();
end
function SneekeeMods:ShowMapEdges()
    BattlefieldMapFrame.BorderFrame.Top:Show();
    BattlefieldMapFrame.BorderFrame.TopLeft:Show();
    BattlefieldMapFrame.BorderFrame.TopRight:Show();
    BattlefieldMapFrame.BorderFrame.Left:Show();
    BattlefieldMapFrame.BorderFrame.BottomLeft:Show();
    BattlefieldMapFrame.BorderFrame.Right:Show();
    BattlefieldMapFrame.BorderFrame.BottomRight:Show();
    BattlefieldMapFrame.BorderFrame.Bottom:Show();
    if self.db.profile.hideclose then
        BattlefieldMapFrame.BorderFrame.CloseButtonBorder:Hide();
    else
        BattlefieldMapFrame.BorderFrame.CloseButtonBorder:Show();
    end
end

--------------------------------------------------------------------------------
-- Map Close Button
--------------------------------------------------------------------------------
function SneekeeMods:CheckCloseButton()
    if self.db.profile.hideclose then
        SneekeeMods:HideCloseButton();
    else
        SneekeeMods:ShowCloseButton();
    end
end
function SneekeeMods:HideCloseButton()
    BattlefieldMapFrame.BorderFrame.CloseButton:Hide();
    BattlefieldMapFrame.BorderFrame.CloseButtonBorder:Hide();
end
function SneekeeMods:ShowCloseButton()
    BattlefieldMapFrame.BorderFrame.CloseButton:Show();
    if self.db.profile.hideedges then
        BattlefieldMapFrame.BorderFrame.CloseButtonBorder:Hide();
    end
end

--------------------------------------------------------------------------------
-- Action Cam
--------------------------------------------------------------------------------
function SneekeeMods:CheckActionCam()
    if self.db.profile.acamon == true and self.db.profile.acambasic == false and self.db.profile.acamignore == false then
        ConsoleExec( "ActionCam full" );
    elseif self.db.profile.acamon == true and self.db.profile.acambasic == true and self.db.profile.acamignore == false then
        ConsoleExec( "ActionCam basic" );
    elseif self.db.profile.acamon == false and self.db.profile.acamignore == false then
    ConsoleExec( "ActionCam off" );
    end
end

--------------------------------------------------------------------------------
-- Collapse Quests Frame
--------------------------------------------------------------------------------
local a = CreateFrame("Frame")
a:RegisterEvent("PLAYER_LOGIN")
a:RegisterEvent("PLAYER_ENTERING_WORLD")
a:RegisterEvent("ADDON_LOADED")

function SneekeeMods:CollapseQuests()
    -- Auto Minimize Quest Objectives at Login and set the minimized Objectives text and button to 50% transparent.
    a:SetScript("OnEvent",function(self,event)
        if event == "PLAYER_LOGIN" then
            ObjectiveTracker_Collapse()
            --	ObjectiveTrackerFrame.HeaderMenu:SetAlpha(.50)
        end
    end)
end

--------------------------------------------------------------------------------
-- Action Bar Gryphons
--------------------------------------------------------------------------------
function SneekeeMods:CheckGryphons()
    if self.db.profile.hidegryph then
        MainMenuBarArtFrame.LeftEndCap:Hide();
        MainMenuBarArtFrame.RightEndCap:Hide();
    else
        MainMenuBarArtFrame.LeftEndCap:Show();
        MainMenuBarArtFrame.RightEndCap:Show();
    end
end
